{#
  Copyright (C) 2021 TU Wien.

  Invenio RDM Records is free software; you can redistribute it and/or modify
  it under the terms of the MIT License; see LICENSE file for more details.
#}

{%- extends "invenio_app_rdm/records/detail.html" %}


{%- block record_header_button -%}
<div style="margin-bottom: 12px;">
  {% if is_preview %}
    {%- set back_page = url_for('invenio_app_rdm_records.record_detail', pid_value=record.id, preview=1) -%}
  {% else %}
    {%- set back_page = url_for('invenio_app_rdm_records.record_detail', pid_value=record.id) -%}
  {% endif %}
  {%- set back_btn_label = _('Back to details') -%}
  <a class="ui button small compact" href="{{ back_page }}"><i class="ui icon angle left"></i> {{ back_btn_label }}</a>
</div>
{%- endblock record_header_button -%}

{% block record_content %}
<h3>{{ export_format }} Export</h3>
<div class="top-padded">
  <pre class="export result mb-10 ml-10">
  {{- exported_record -}}
  </pre>
</div>
{%- endblock record_content %}

{% block record_files %}{% endblock %}
{% block record_details %}{% endblock %}
{% block record_footer %}{% endblock %}
