{#
  Copyright (C) 2019-2022 CERN

  Invenio App RDM is free software; you can redistribute it and/or modify it
  under the terms of the MIT License; see LICENSE file for more details.
#}

{% macro records_list(
    title="Recent uploads",
    fetch_url="/api/records?sort=newest&size=10"
  )
%}
  <div
    id="records-list"
    data-fetch-url="{{ fetch_url }}"
    data-title="{{ title }}"
  ></div>

  {{ webpack["invenio-app-rdm-frontpage.js"]}}
{% endmacro %}
