/*
 *   Copyright (C) 2022 data-futures.
 *
 * Invenio App RDM is free software; you can redistribute it and/or modify
 * it under the terms of the MIT License; see LICENSE file for more details.
 */

.iiif-simple-preview {
    display: flex;
    justify-content: center;
}

.iiif-simple-preview img {
    max-width: 100%;
}

